@@ -435,7 +435,7 @@ class Deploy(object):
             elif 'tar.gz' in name and 's3' not in name:
                 
                 self.makedir_safe("downloads")
-                shutil.copy(name, "./downloads/{}".format(i))
+                shutil.copy(name, "./downloads/{}/".format(i))
                 
                 with tarfile.open(
                     glob.glob("./downloads/{}/*.tar.gz".format(i))[0]
